"""This module defines classes for representing and managing data related to Time-of-Flight (ToF) cameras."""

from dataclasses import dataclass, field
from typing import Optional

from dataspree.inference.sensor.data.camera import Camera, CameraData


@dataclass
class TofCamera(Camera):
    """Represents the configuration and operational settings of a Time-of-Flight (ToF) camera.

    Attributes:
        operating_mode (Optional[str]): The current operating mode of the ToF camera.
        operating_modes (Optional[List[str]]): List of supported operating modes for the ToF camera.
        distortion_correction (Optional[bool]): Flag indicating if distortion correction is enabled.
        ambiguity_filter_threshold (Optional[int]): Threshold value for ambiguity filtering.
    """

    operating_mode: Optional[str] = None
    operating_modes: Optional[list[str]] = field(default_factory=list)

    distortion_correction: Optional[bool] = None
    ambiguity_filter_threshold: Optional[int] = None


@dataclass
class TofCameraData(CameraData):
    """Data structure for capturing specific data associated with a ToF camera.

    Inherits:
        CameraData: Contains the foundational data attributes shared by all camera types.
    """
